@@ -53,8 +53,8 @@ class Stats(object):
         self.get_widget("explore_everything").add(self.timechart)
         self.get_widget("explore_everything").show_all()
 
-        runtime.dispatcher.add_handler('activity_updated', self.after_fact_update)
-        runtime.dispatcher.add_handler('day_updated', self.after_fact_update)
+        runtime.storage.connect('activities-changed',self.after_fact_update)
+        runtime.storage.connect('facts-changed',self.after_fact_update)
 
         self.init_stats()
 
@@ -67,7 +67,7 @@ class Stats(object):
 
 
     def init_stats(self):
-        self.stat_facts = runtime.storage.get_facts(dt.date(1970, 1, 1), dt.date.today())
+        self.stat_facts = runtime.storage.get_facts(dt.date(1970, 1, 2), dt.date.today())
 
         if not self.stat_facts or self.stat_facts[-1]["start_time"].year == self.stat_facts[0]["start_time"].year:
             self.get_widget("explore_controls").hide()
@@ -97,44 +97,40 @@ class Stats(object):
 
             year_box.show_all()
 
-        self.chart_category_totals = charting.HorizontalBarChart(value_format = "%.1f",
-                                                            bars_beveled = False,
-                                                            max_bar_width = 20,
-                                                            legend_width = 70)
+        self.chart_category_totals = charting.Chart(value_format = "%.1f",
+                                                       max_bar_width = 20,
+                                                       legend_width = 70,
+                                                       interactive = False)
         self.get_widget("explore_category_totals").add(self.chart_category_totals)
 
 
-        self.chart_weekday_totals = charting.HorizontalBarChart(value_format = "%.1f",
-                                                            bars_beveled = False,
-                                                            max_bar_width = 20,
-                                                            legend_width = 70)
+        self.chart_weekday_totals = charting.Chart(value_format = "%.1f",
+                                                      max_bar_width = 20,
+                                                      legend_width = 70,
+                                                      interactive = False)
         self.get_widget("explore_weekday_totals").add(self.chart_weekday_totals)
 
-        self.chart_weekday_starts_ends = charting.HorizontalDayChart(bars_beveled = False,
-                                                                animate = False,
-                                                                max_bar_width = 20,
-                                                                legend_width = 70)
+        self.chart_weekday_starts_ends = charting.HorizontalDayChart(max_bar_width = 20,
+                                                                     legend_width = 70)
         self.get_widget("explore_weekday_starts_ends").add(self.chart_weekday_starts_ends)
 
-        self.chart_category_starts_ends = charting.HorizontalDayChart(bars_beveled = False,
-                                                                animate = False,
-                                                                max_bar_width = 20,
-                                                                legend_width = 70)
+        self.chart_category_starts_ends = charting.HorizontalDayChart(max_bar_width = 20,
+                                                                      legend_width = 70)
         self.get_widget("explore_category_starts_ends").add(self.chart_category_starts_ends)
 
 
 
 
         #ah, just want summary look just like all the other text on the page
-        class CairoText(graphics.Area):
+        class CairoText(graphics.Scene):
             def __init__(self, fontsize = 10):
-                graphics.Area.__init__(self)
+                graphics.Scene.__init__(self)
                 self.text = ""
                 self.fontsize = fontsize
 
             def set_text(self, text):
                 self.text = text
-                self.redraw_canvas()
+                self.redraw()
 
             def on_expose(self):
                 # now for the text - we want reduced contrast for relaxed visuals
@@ -176,7 +172,7 @@ class Stats(object):
                 label.set_text(_("""There is no data to generate statistics yet.
 A week of usage would be nice!"""))
             else:
-                label.set_text(_(u"Collecting data — check back after a week has passed!"))
+                label.set_text(_("Collecting data — check back after a week has passed!"))
 
             label.show()
             return
@@ -386,13 +382,13 @@ A week of usage would be nice!"""))
             summary += "\n\n" + _("Hamster would like to observe you some more!")
         elif early_percent >= 20:
             summary += "\n\n" + _("With %s percent of all facts starting before \
-9am you seem to be an early bird.") % ("<b>%d</b>" % early_percent)
+9am, you seem to be an early bird.") % ("<b>%d</b>" % early_percent)
         elif late_percent >= 20:
             summary += "\n\n" + _("With %s percent of all facts starting after \
-11pm you seem to be a night owl.") % ("<b>%d</b>" % late_percent)
+11pm, you seem to be a night owl.") % ("<b>%d</b>" % late_percent)
         elif short_percent >= 20:
             summary += "\n\n" + _("With %s percent of all tasks being shorter \
-than 15 minutes you seem to be a busy bee.") % ("<b>%d</b>" % short_percent)
+than 15 minutes, you seem to be a busy bee.") % ("<b>%d</b>" % short_percent)
 
         self.explore_summary.set_text(summary)
 
@@ -410,7 +406,7 @@ than 15 minutes you seem to be a busy bee.") % ("<b>%d</b>" % short_percent)
         self.stats(button.year)
 
 
-    def after_fact_update(self, event, date):
+    def after_fact_update(self, event):
         self.stat_facts = runtime.storage.get_facts(dt.date(1970, 1, 1), dt.date.today())
         self.stats()
 
@@ -428,9 +424,6 @@ than 15 minutes you seem to be a busy bee.") % ("<b>%d</b>" % short_percent)
         self.close_window()
 
     def close_window(self):
-        runtime.dispatcher.del_handler('activity_updated', self.after_fact_update)
-        runtime.dispatcher.del_handler('day_updated', self.after_fact_update)
-
         if not self.parent:
             gtk.main_quit()
         else:
